[![](https://iarduino.ru/img/logo.svg)](https://iarduino.ru)[![](https://wiki.iarduino.ru/img/git-shop.svg?3)](https://iarduino.ru) [![](https://wiki.iarduino.ru/img/git-wiki.svg?2)](https://wiki.iarduino.ru) [![](https://wiki.iarduino.ru/img/git-lesson.svg?2)](https://lesson.iarduino.ru)[![](https://wiki.iarduino.ru/img/git-forum.svg?2)](http://forum.trema.ru)

# pyiArduinoI2Crelay

**Данная библилотека (модуль) позволяет управлять электронными модулями (устройствами) твердотельных реле, механических реле и силовых ключей от iArduino.ru по шине I2C на Raspberry Pi c версией платы 2.0 (выпускаемые после 2012 года).**


**This is a Python3 module for Raspberry Pi, board rev2 (made after 2012). It can control solid state relays, mechanical relays and power mosfet modules made by iarduino.ru via I2C bus.**
